@@ -49,6 +49,8 @@
  * public headers just yet. So we have this exciting trick instead. */
 #define CHAFA_TERM_SEQ_ARGS ,
 
+/* --- Available in 1.6+ --- */
+
 #define CHAFA_TERM_SEQ_AVAILABILITY CHAFA_AVAILABLE_IN_1_6
 
 /**
@@ -842,6 +844,135 @@ CHAFA_TERM_SEQ_DEF(end_sixels, END_SIXELS, 0, none, void)
  **/
 CHAFA_TERM_SEQ_DEF(repeat_char, REPEAT_CHAR, 1, none, guint, CHAFA_TERM_SEQ_ARGS guint n)
 
+/* --- Available in 1.8+ --- */
+
+#undef CHAFA_TERM_SEQ_AVAILABILITY
+#define CHAFA_TERM_SEQ_AVAILABILITY CHAFA_AVAILABLE_IN_1_8
+
+/**
+ * chafa_term_info_emit_begin_kitty_immediate_image_v1:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ * @bpp: Bits per pixel
+ * @width_pixels: Image width in pixels
+ * @height_pixels: Image height in pixels
+ * @width_cells: Target width in cells
+ * @height_cells: Target height in cells
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_BEGIN_KITTY_IMAGE_IMMEDITATE.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * @bpp must be set to either 24 for RGB data, 32 for RGBA, or 100 to embed a
+ * PNG file.
+ *
+ * This sequence must be followed by zero or more paired sequences of
+ * type #CHAFA_TERM_SEQ_BEGIN_KITTY_IMAGE_CHUNK and #CHAFA_TERM_SEQ_END_KITTY_IMAGE_CHUNK
+ * with base-64 encoded image data between them.
+ *
+ * When the image data has been transferred, #CHAFA_TERM_SEQ_END_KITTY_IMAGE must
+ * be emitted.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(begin_kitty_immediate_image_v1, BEGIN_KITTY_IMMEDIATE_IMAGE_V1, 5, none, guint, CHAFA_TERM_SEQ_ARGS guint bpp, guint width_pixels, guint height_pixels, guint width_cells, guint height_cells)
+
+/**
+ * chafa_term_info_emit_end_kitty_image:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_END_KITTY_IMAGE.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(end_kitty_image, END_KITTY_IMAGE, 0, none, void)
+
+/**
+ * chafa_term_info_emit_begin_kitty_image_chunk:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_BEGIN_KITTY_IMAGE_CHUNK.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(begin_kitty_image_chunk, BEGIN_KITTY_IMAGE_CHUNK, 0, none, void)
+
+/**
+ * chafa_term_info_emit_end_kitty_image_chunk:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_END_KITTY_IMAGE_CHUNK.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(end_kitty_image_chunk, END_KITTY_IMAGE_CHUNK, 0, none, void)
+
+/**
+ * chafa_term_info_emit_begin_iterm2_image:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ * @width: Image width in character cells
+ * @height: Image height in character cells
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_BEGIN_ITERM2_IMAGE_IMMEDITATE.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * This sequence must be followed by base64-encoded image file data. The image
+ * can be any format supported by MacOS, e.g. PNG, JPEG, TIFF, GIF. When the
+ * image data has been transferred, #CHAFA_TERM_SEQ_END_ITERM2_IMAGE must be
+ * emitted.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(begin_iterm2_image, BEGIN_ITERM2_IMAGE, 2, none, guint, CHAFA_TERM_SEQ_ARGS guint width, guint height)
+
+/**
+ * chafa_term_info_emit_end_iterm2_image:
+ * @term_info: A #ChafaTermInfo
+ * @dest: String destination
+ *
+ * Prints the control sequence for #CHAFA_TERM_SEQ_END_ITERM2_IMAGE.
+ *
+ * @dest must have enough space to hold
+ * #CHAFA_TERM_SEQ_LENGTH_MAX bytes, even if the emitted sequence is
+ * shorter. The output will not be zero-terminated.
+ *
+ * Returns: Pointer to first byte after emitted string
+ *
+ * Since: 1.8
+ **/
+CHAFA_TERM_SEQ_DEF(end_iterm2_image, END_ITERM2_IMAGE, 0, none, void)
+
 #undef CHAFA_TERM_SEQ_AVAILABILITY
 
 #undef CHAFA_TERM_SEQ_ARGS
